==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Input/wavpack/translations/wavpack_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Wtyczka WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Pliki WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="132"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O wtyczce WavPack Audio</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Wtyczka WavPack dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="134"/>
        <source>WavPack library version:</source>
        <translation>Wersja biblioteki WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="136"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="66"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Ratio</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
</context>
</TS>

==> qmmp-0.5.2.tar.bz2: qmmp-0.5.2/src/plugins/Input/wavpack/translations/wavpack_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Wtyczka WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Pliki WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="153"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O wtyczce WavPack Audio</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="154"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Wtyczka WavPack dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="155"/>
        <source>WavPack library version:</source>
        <translation>Wersja biblioteki WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="157"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Ratio</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="74"/>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
</context>
</TS>
